==> libwebsockets-4.1.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/libwebsockets/LibwebsocketsTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "websockets-evlib_uv" for configuration "None"
set_property(TARGET websockets-evlib_uv APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_uv PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libuv.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_uv.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_uv.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_uv )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_uv "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_uv.so" )

# Import target "websockets-evlib_glib" for configuration "None"
set_property(TARGET websockets-evlib_glib APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_glib PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libglib-2.0.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_glib.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_glib.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_glib )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_glib "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_glib.so" )

# Import target "websockets-evlib_ev" for configuration "None"
set_property(TARGET websockets-evlib_ev APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_ev PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libev.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_ev.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_ev.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_ev )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_ev "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_ev.so" )

# Import target "websockets_shared" for configuration "None"
set_property(TARGET websockets_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets_shared PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "dl;/usr/lib/libcap.so;dl;/usr/lib/libz.so;/usr/lib/libssl.so;/usr/lib/libcrypto.so;ssl;crypto"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets.so.17"
  IMPORTED_SONAME_NONE "libwebsockets.so.17"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets_shared )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets_shared "${_IMPORT_PREFIX}/lib/libwebsockets.so.17" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libwebsockets-4.1.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/libwebsockets/LibwebsocketsTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "websockets-evlib_uv" for configuration "None"
set_property(TARGET websockets-evlib_uv APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_uv PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libuv.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_uv.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_uv.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_uv )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_uv "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_uv.so" )

# Import target "websockets-evlib_glib" for configuration "None"
set_property(TARGET websockets-evlib_glib APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_glib PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libglib-2.0.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_glib.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_glib.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_glib )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_glib "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_glib.so" )

# Import target "websockets-evlib_ev" for configuration "None"
set_property(TARGET websockets-evlib_ev APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets-evlib_ev PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "websockets_shared;/usr/lib/libev.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_ev.so"
  IMPORTED_SONAME_NONE "libwebsockets-evlib_ev.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets-evlib_ev )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets-evlib_ev "${_IMPORT_PREFIX}/lib/libwebsockets-evlib_ev.so" )

# Import target "websockets_shared" for configuration "None"
set_property(TARGET websockets_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(websockets_shared PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_NONE "dl;/usr/lib/libssl.so;/usr/lib/libcrypto.so;ssl;crypto;/usr/lib/libcap.so;dl;/usr/lib/libz.so"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwebsockets.so.17"
  IMPORTED_SONAME_NONE "libwebsockets.so.17"
  )

list(APPEND _IMPORT_CHECK_TARGETS websockets_shared )
list(APPEND _IMPORT_CHECK_FILES_FOR_websockets_shared "${_IMPORT_PREFIX}/lib/libwebsockets.so.17" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
